#!/gnuplot
GNUTERM = 'wxt'
reset session

set term wxt 1 size 2400,1200 persist font 'Helvetica, 8'
set termoption enhanced
set termoption dash
set mxtics
set mytics
set grid

#
# Set overall margins for the combined set of plots and size them
# to generate a requested inter-plot spacing
#
if (!exists("MP_LEFT"))   MP_LEFT = .1
if (!exists("MP_RIGHT"))  MP_RIGHT = .95
if (!exists("MP_BOTTOM")) MP_BOTTOM = .14
if (!exists("MP_TOP"))    MP_TOP = .9
if (!exists("MP_xGAP"))   MP_xGAP = 0.06
if (!exists("MP_yGAP"))   MP_yGAP = 0.1

set title font "Helvetica, 14"

set label "[EvAX-6.1; © Janis Timoshenko (2023)]" at screen 0.8,0.98


stats 'output_files/output.dat' u (myTitle2=strcol(2),0) every ::-2::-1 nooutput
stats 'output_files/output.dat' u (myTitle1=strcol(1),0) every ::-2::-1 nooutput

set multiplot layout 2,2 columnsfirst title  "EvAX iteration: ".myTitle1." Residual:".myTitle2 \
              margins screen MP_LEFT, MP_RIGHT, MP_BOTTOM, MP_TOP spacing screen MP_xGAP, MP_yGAP

set style line 2 lc rgb '#0060ad' lt 1 lw 4
set style line 1 dashtype 1 lc rgb 'red' lw 2

set style line 4 lc rgb 'black' lt 1 lw 4
set style line 3 dashtype 1 lc rgb 'red' lw 2


set format y "%.1f"
set key

unset yrange
unset xrange
set xlabel 'Wavenumber, k (Å^{-1})'
set ylabel 'EXAFS'
plot 'output_files/ipolEXAFS.dat' using 1:($2*$1*$1) with line ls 2 title 'Experiment', 'output_files/EXAFS.dat' using 1:($2*$1*$1) with line ls 1  title 'fit'

set ylabel 'Residual'
set xlabel 'Iteration'


plot 'output_files/output.dat' using 1:2 with line ls 2
#set xlabel 'xlabel'
unset logscale

set xlabel 'Distance, R(Å)'
set ylabel 'FT of EXAFS'
set xrange [0:10]
plot 'output_files/expFT.dat' using 1:4 with line ls 2 title 'Experiment', 'output_files/ft.dat' using 1:4 with line ls 1 title 'fit'

set xlabel "Distance, R (Å)"
set ylabel "RDF g(R) (atoms/Å)"
set grid 

set xrange [0:10]
set xtics 0.5
set key
 
set style line 2 lc rgb '#0060ad' lt 1 lw 3 # --- blue
set style line 1 dashtype 1 lc rgb "red" lw 2 

set xrange [0:6]
set key autotitle columnheader 
plot for [i=2:*] 'output_files/rdf.dat' using 1:(column(i))  with line lw 3


unset multiplot

pause 10
reread